@@ -1,12 +1,5 @@
 from dycow import (
-    path,
-    system,
-    urlparse,
-    json_loads,
-    BaseHTTPRequestHandler,
-    search,
-    argv,
-    HTTPServer
+    search
 )
 
 
@@ -15,13 +8,7 @@ def grep(content: str, pattern: str) -> list:
     A dump grep method on a content lol
 
     """
-    results = []
-    for index, line in enumerate(content.split("\n")):
-        if search(pattern, line):
-            results.append(index)
-
-    return results
-
+    return [index if search(pattern, line) else None for index, line in enumerate(content.split("\n"))]
 
 
 def loop_bodies(k: int, url_path: str, lines: list, command: list, body_params: list, query_params: list):
@@ -38,19 +25,19 @@ def loop_bodies(k: int, url_path: str, lines: list, command: list, body_params:
     for j in range(k, len(lines)):
         if len(lines[j]) <= 2:
             break
-        
+
         if "var:" in lines[j]:
             body_params = lines[j].split("var:")[1].replace("\n", "").replace(" ", "").split(",")
 
         if "cmd:" in lines[j]:
-            cmd = lines[j].split("cmd:")[1].lstrip().rstrip()
-            command.append(cmd)
+            command.append(lines[j].split("cmd:")[1].lstrip().rstrip())
 
         if "res:" in lines[j]:
             res = lines[j].split("res:")[1].lstrip().rstrip()
 
     return query_params, body_params, command, res
 
+
 def parse_conf_file(conf_file: str) -> list:
     """
     We parse the content of the configuration file
@@ -69,17 +56,17 @@ def parse_conf_file(conf_file: str) -> list:
                 query_params, body_params, command = [], [], []
 
                 (query_params,
-                body_params,
-                command,
-                res) = loop_bodies(i, url_path, lines, command, body_params, query_params)
+                 body_params,
+                 command,
+                 res) = loop_bodies(i, url_path, lines, command, body_params, query_params)
 
                 reqs.append({
-                        "type": _type,
-                        "url_path": url_path,
-                        "query_params": query_params,
-                        "body_params": body_params,
-                        "command": command,
-                        "res": res
+                    "type": _type,
+                    "url_path": url_path,
+                    "query_params": query_params,
+                    "body_params": body_params,
+                    "command": command,
+                    "res": res
                 })
 
         return reqs
